#include <pthread.h>
#include <gtk/gtk.h>
#include <getopt.h>
#include <string.h>
#include "specimen.h"
#include "gui/gui.h"
#include "midi.h"
#include "driver.h"
#include "lfo.h"
#include "patch.h"
#include "mixer.h"
#include "beef.h"
#include "lashdriver.h"

int main(int argc, char *argv[])
{
     int opt;
     int longopt_index;
     static struct option long_options[] = {
	{"iname",1,NULL,'i'},
	{"bank",1,NULL,'b'},
	{NULL,0,NULL,0}
     };
     char* forced_instance_name = NULL;

     lashdriver_init(&argc, &argv);
     gtk_init(&argc, &argv);

     /* constructors */
     driver_init();
     lfo_init();
     mixer_init();
     patch_init();
     gui_init();

     /* command line arguments handling */
     while((opt = getopt_long(argc, argv, "i:b:", long_options, &longopt_index))>0)
     {
     	switch(opt){
	     case 'b':
	     	  beef_read(optarg);
		  gui_refresh();
		  break;
	     case 'i':
	          forced_instance_name = strdup(optarg);
		  break;
	}
     }
     
     /* start */
     midi_start();
     driver_start(0, forced_instance_name);
     lashdriver_start();

     gtk_main();

     /* stop */
     midi_stop();
     driver_stop();

     /* destructors */
     patch_shutdown();
     mixer_shutdown();

     debug("Goodbye.\n");
     return 0;
}

